@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10649 2017-12-17 10:04:42Z Lavender $
+# $Id: build_templates.py 10810 2018-03-04 14:28:02Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-17 18:04:42 +0800 (週日, 17 十二月 2017) $
-# $Revision: 10649 $
+# $Date: 2018-03-04 22:28:02 +0800 (週日, 04 三月 2018) $
+# $Revision: 10810 $
 
 import os
 import sys
 import shutil
 
+import cms
+
 from django.core.management.base import BaseCommand
 from django.conf import settings
 
@@ -61,7 +63,7 @@ class Command(BaseCommand):
                     os.remove(dbPath)
                 shutil.copyfile(backupDbPath, dbPath)
             else:
-                os.system("%s manage.py migrate" % sys.executable)
+                os.system("%s manage.py migrate --noinput" % sys.executable)
                 shutil.copyfile(dbPath, backupDbPath)
 
             # get_template
@@ -116,10 +118,17 @@ class Command(BaseCommand):
                 continue
 
             # dumpdata
-            error = os.system(
-                ("%s manage.py dumpdata cms djangocms_text_ckeditor "
-                 "cmsplugin_filer_image > fixtures/initial_data.json") % 
-                 (sys.executable,))
+            if cms.__version__.startswith('3.5'):
+                error = os.system(
+                    ("%s manage.py cms_dumpdata "
+                     "fixtures/initial_data.json -n") % 
+                    (sys.executable,))
+            else:
+                error = os.system(
+                    ("%s manage.py dumpdata cms djangocms_text_ckeditor "
+	                 "cmsplugin_filer_image > fixtures/initial_data.json") %
+                    (sys.executable,))
+
             if not error == 0:
                 logger.error(
                     "dumpdata error code: %d, from template: %s" % 
