@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 10152 2017-08-08 05:33:45Z Lavender $
+# $Id: cms_dumpdata.py 10809 2018-03-04 09:29:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-08 13:33:45 +0800 (Tue, 08 Aug 2017) $
-# $Revision: 10152 $
+# $Date: 2018-03-04 17:29:56 +0800 (週日, 04 三月 2018) $
+# $Revision: 10809 $
 
 import os
 import sys
@@ -29,6 +29,13 @@ from django.db.models.query import QuerySet
 class Command(BaseCommand):
 
     help = 'Dump all data include filer.File to initial_data.json'
+
+    def add_arguments(self, parser):
+        parser.add_argument('path', type=str, help="path")
+        parser.add_argument(
+            '-n', '--noAuth', 
+            action='store_true',
+            help="No export auth data.")
     
     def handle(self, *args, **options):
         app = get_app('filer')
@@ -53,25 +60,45 @@ class Command(BaseCommand):
         os.system(
             "%s manage.py dumpdata auth > authData.json" %  
             sys.executable)
+
+        os.system(
+            "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
+            sys.executable)
             
         os.system(
             ("%s manage.py dumpdata "
-             "-e auth -e filer -e contenttypes > otherData.json") % 
+             "-e auth -e filer -e contenttypes -e cms.Treenode "
+             "> otherData.json") % 
              sys.executable)
         
         with open('authData.json') as f:
             content = f.read()
             authData = json.loads(content[content.index('['):])
+        with open('treenodeData.json') as f:
+            content = f.read()
+            treenodeData = json.loads(content[content.index('['):])
         with open('otherData.json') as f:
             content = f.read()
             otherData = json.loads(content[content.index('['):])
+
+        data = []
+
+        if not options['noAuth']:
+            for ele in authData:
+                data.append(ele)
+
         
         for ele in filerData:
-            authData.append(ele)
+            data.append(ele)
+        for ele in treenodeData:
+            data.append(ele)
         for ele in otherData:
-            authData.append(ele)
+            data.append(ele)
 
-        with open('initial_data.json', 'w') as f:
-            content = f.write(json.dumps(authData))
+        path = os.path.join(options['path'])
+
+        with open(path, 'w') as f:
+            content = f.write(json.dumps(data))
         os.remove('authData.json')
+        os.remove('treenodeData.json')
         os.remove('otherData.json')
