@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10626 2017-12-10 09:05:41Z Lavender $
+# $Id: create_zip.py 10818 2018-03-05 08:44:31Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
-# $Revision: 10626 $
+# $Date: 2018-03-05 16:44:31 +0800 (週一, 05 三月 2018) $
+# $Revision: 10818 $
 
 import os
 import shutil
@@ -23,6 +23,8 @@ import hashlib
 import datetime
 import traceback
 
+import cms
+
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
 from django.template import Context
@@ -90,6 +92,7 @@ class Command(BaseCommand):
                     ROOT_DIR_PATH, 'MANIFAST.INFO'), 'wb') as f:
                     manifast = json.dumps({
                         'upc': upc, 
+                        'DjangoCMSVersion': cms.__version__, 
                         'complexity': complexity,
                         'createTime': str(datetime.datetime.now()),
                         'ZephyrusVersion': ZEPHYRUS_VERSION,
