@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: cms_plugins.py 11182 2018-07-29 13:55:04Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-07-29 22:55:04 +0900 (週日, 29 七月 2018) $
+# $Revision: 11182 $
 
 from django.db.models import Count
 from django.template.loader import select_template
@@ -32,6 +32,8 @@ Product = get_model('catalogue', 'Product')
 
 if hasattr(Product, 'tags'):
     hasTags = True
+else:
+    hasTags = False
 
 class FeaturedPlugin(CMSPluginBase):
     model = OscarFeatured
