@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: cms_plugins.py 11190 2018-08-05 13:08:39Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-08-05 22:08:39 +0900 (週日, 05 八月 2018) $
+# $Revision: 11190 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -21,7 +21,8 @@ from django.utils.translation import ugettext as _
 from django.template.loader import select_template
 
 from Zephyrus.comment import settings as _settings
-from Zephyrus.comment.models import CommentPlugin, Comment, RecentResponsePlugin
+from Zephyrus.comment.models import (
+    CommentPlugin, Comment, RecentResponsePlugin, CommentConfig)
 
 class CMSCommentPlugin(CMSPluginBase):
     model = CommentPlugin
@@ -29,8 +30,6 @@ class CMSCommentPlugin(CMSPluginBase):
     name = _("Comment")
     render_template =_settings.ZEPHYRUS_COMMENT_DEFAULT_TEMPLATE
 
-    
-
     def get_render_template(self, context, instance, placeholder):
         return select_template([
             instance.renderTemplate,
@@ -41,7 +40,14 @@ class CMSCommentPlugin(CMSPluginBase):
         request = context['request']
         url = request.build_absolute_uri(request.path)
 
-        comments = Comment.objects.filter(url=url) 
+        comments = Comment.objects.filter(url=url)
+
+        obj, created = CommentConfig.objects.get_or_create(
+            url=url,
+            defaults={'useFbComment': False},
+        )
+        obj.useFbComment = instance.useFbComment
+        obj.save()
         
         context.update({
             'plugin': instance,
